package Task::Git::LongList1;

use 5.005;
use strict;
use warnings;

our $VERSION = '0.02';

1;

__END__


=head1 NAME

Task::Git::LongList1 -
  Perl extension for installing git modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Task::Git::LongList1'

=head1 DESCRIPTION

Task::Git::LongList1 is the first part of three parts.
  It's based on the long list as given by 01Modules.index

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it 
and/or modify it under the same terms as Perl itself, 
either Perl version 5.005, or at your option, any later 
version of Perl 5 you may have available.

=cut
